# ResponseGT
ResponseGT is a software that computes electrical/mechanical flow within a graph network.

## 1. Installation

Therefore, please follow the manual installation instructions provided below:

* Install Python version 3.13 on your computer.
* Git Clone this repo: ```https://github.com/owuordickson/response-gt```
* Extract the ```source code``` folder named **'response-gt'** and save it to your preferred location on your PC.
* Open a terminal application such as ```CMD```. 
* Navigate to the location where you saved the **'response-gt'** folder using the terminal. 
* Execute the following commands:

```bash
cd response-gt
pip install --upgrade pip
pip install -r requirements.txt
pip install .
```

## 2. Usage

To run the GUI application, please follow these steps:

* Open a terminal application such as CMD.
* Execute the following command:

```bash
ResponseGT
```
